@@ -14,6 +14,11 @@ import aws_cdk.aws_lambda
 import aws_cdk.aws_route53
 import aws_cdk.core
 import constructs
-__all__ = []
+
+__jsii_assembly__ = jsii.JSIIAssembly.load("@aws-cdk/aws-certificatemanager", "1.34.1", __name__[0:-6], "aws-certificatemanager@1.34.1.jsii.tgz")
+
+__all__ = [
+    "__jsii_assembly__",
+]
 
 publication.publish()
